# Class::Enum

[![Gem Version](https://badge.fury.io/rb/class-enum.svg)](https://badge.fury.io/rb/class-enum)

'Classial' class enum for Ruby

```ruby
class Animal
	include Class::Enum
	
	attr_reader :sound
	
	def initialize(sound)
		@sound = sound
	end
	
	field :CAT, "meow"
	field :DOG, "bark"
	field :BIRD, "tweet"
end

puts Animal::CAT.sound # meow

case Animal::CAT
when Animal
	puts "An animal"
else
	puts "X"
end
# An animal

Animal::CAT.instance_of?(Animal) # => true
Animal::CAT.class # => Animal
```

## Requirements
- No

## Usage
See [documentation](http://www.rubydoc.info/gems/class-enum)

## Examples

### Using block
```ruby
class Animal
	include Class::Enum
	
	attr_reader :block
	
	def initialize(&block)
		@block = block
	end
	
	field :CAT do
		puts "meow"
	end
end

Animal::CAT.block.call # meow
```

### Using keyword arguments
You can keyword arguments only if ruby 2.0+.
If not ruby 2.0+, this gem doesn't use keyword arguments

```ruby
class Animal
	include Class::Enum
	
	attr_reader :sound
	
	def initialize(sound:)
		@sound = sound
	end
	
	field :CAT, sound: "meow"
end

puts Animal::CAT.sound # meow
```

## Author
Sputnik Gugja (sputnikgugja@gmail.com)

## License
This is free software released into the public domain (CC0 license).

See `LICENSE` file.

